# API7 Python SDK

This SDK is a pure Python package that helps you interact with API7 Facial Recognition API.

The API7 Facial Recognition API is a JSON REST based API that lets you:
1. Register persons using their face images
2. Search for registered persons
3. Group persons into `Collections`
4. Perform `liveness` checks to see if a photo is spoofed.

# How to use

Install the package via:
```
pip install API7
```

# Documentation

Our documentation can be found [here](https://docs.api7cloud.com/python/)
